@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 from . import config, datasets
 from .core import istask
 from .local import get_sync as get
@@ -9,7 +7,14 @@ try:
 except ImportError:
     pass
 try:
-    from .base import visualize, compute, persist, optimize, is_dask_collection
+    from .base import (
+        annotate,
+        compute,
+        is_dask_collection,
+        optimize,
+        persist,
+        visualize,
+    )
 except ImportError:
     pass
 
